@@ -26,13 +26,13 @@
 using namespace Rcpp;
 using namespace IsoSpec;
 
-TotalProbFixedEnvelope mkIsoG(Iso& iso, int algo, double stopCondition, bool trim, bool get_confs)
+FixedEnvelope mkIsoG(Iso& iso, int algo, double stopCondition, bool trim, bool get_confs)
 {
     switch(algo)
     {
         case ISOSPEC_ALGO_LAYERED_ESTIMATE: // Not used anymore, just fall through to the next case
-        case ISOSPEC_ALGO_LAYERED: return TotalProbFixedEnvelope(std::move(iso), stopCondition, trim, get_confs, false, true, true);
-        case ISOSPEC_ALGO_ORDERED: return TotalProbFixedEnvelope(std::move(iso), stopCondition, true, get_confs, false, true, true); // Using the ordered algo in R is *completely* pointless today
+        case ISOSPEC_ALGO_LAYERED: return FixedEnvelope::FromTotalProb(std::move(iso), stopCondition, trim, get_confs);
+        case ISOSPEC_ALGO_ORDERED: return FixedEnvelope::FromTotalProb(std::move(iso), stopCondition, true, get_confs); // Using the ordered algo in R is *completely* pointless today
                                                                                                                   // The only point of ordered algo is when one is using the generator
                                                                                                                   // interface, which we are not exposing in R
                                                                                                                   // We'll just do layered, trim and sort it afterwards - it's equivalent
@@ -53,7 +53,8 @@ NumericMatrix Rinterface(
     int                     hashSize = 1000,
     double                  step = .3,
     bool                    showCounts = false,
-    bool                    trim = true
+    bool                    trim = true,
+    double                  charge = 1.0
 ){
 
     unsigned int dimNumber = molecule.size();
@@ -76,7 +77,7 @@ NumericMatrix Rinterface(
             if( element[j] == molecule_names[i] )
             {
                 counter++;
-                stdIsotopeMasses.push_back( mass[j] );
+                stdIsotopeMasses.push_back( mass[j] / charge );
                 stdIsotopeProbabilities.push_back( abundance[j] );
                 if( showCounts )
                     stdIsotopeTags.push_back( isotope[j] );
@@ -135,7 +136,7 @@ NumericMatrix Rinterface(
     }
 
     // The remaining (layered) algos
-    TotalProbFixedEnvelope TAB = mkIsoG(iso, algo, stopCondition, trim, showCounts);
+    FixedEnvelope TAB = mkIsoG(iso, algo, stopCondition, trim, showCounts);
 
     const double* probs = TAB.probs();
     const double* masses = TAB.masses();
